# Discoin for Python

This is the official discoin library for python. Here is discoin's [Gitbook](https://discoin.gitbook.io/docs/)

## Requirements
* Python 3.6 or up
* aiohttp

## Installation
```bash
$ pip install discoin
```

Documentation can be found [here](https://discoinpy.readthedocs.io)

## Credits
* [Dr_Ari_Gami](https://github.com/Dr-Ari-Gami/) (Main Developer)
* [DeveloperAnonymous](https://github.com/DeveloperAnonymous) (Collaborator)
* [Theelgirl](https://github.com/Theelgirl) (Collaborator)
* [PizzaFox](https://github.com/pizzafox) (Main developer of discoin)
* [Austin Huang](https://github.com/austinhuang0131) (Owner of discoin)